# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class Program(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Program - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'published': 'bool',
            'topics': 'list[BaseTopicEntitiy]',
            'tags': 'list[str]',
            'modified_by': 'AddressableEntityRef',
            'date_modified': 'datetime',
            'published_by': 'AddressableEntityRef',
            'date_published': 'datetime',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'published': 'published',
            'topics': 'topics',
            'tags': 'tags',
            'modified_by': 'modifiedBy',
            'date_modified': 'dateModified',
            'published_by': 'publishedBy',
            'date_published': 'datePublished',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._published = None
        self._topics = None
        self._tags = None
        self._modified_by = None
        self._date_modified = None
        self._published_by = None
        self._date_published = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Program.
        The globally unique identifier for the object.

        :return: The id of this Program.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Program.
        The globally unique identifier for the object.

        :param id: The id of this Program.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Program.


        :return: The name of this Program.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Program.


        :param name: The name of this Program.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this Program.


        :return: The description of this Program.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Program.


        :param description: The description of this Program.
        :type: str
        """
        
        self._description = description

    @property
    def published(self):
        """
        Gets the published of this Program.


        :return: The published of this Program.
        :rtype: bool
        """
        return self._published

    @published.setter
    def published(self, published):
        """
        Sets the published of this Program.


        :param published: The published of this Program.
        :type: bool
        """
        
        self._published = published

    @property
    def topics(self):
        """
        Gets the topics of this Program.


        :return: The topics of this Program.
        :rtype: list[BaseTopicEntitiy]
        """
        return self._topics

    @topics.setter
    def topics(self, topics):
        """
        Sets the topics of this Program.


        :param topics: The topics of this Program.
        :type: list[BaseTopicEntitiy]
        """
        
        self._topics = topics

    @property
    def tags(self):
        """
        Gets the tags of this Program.


        :return: The tags of this Program.
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """
        Sets the tags of this Program.


        :param tags: The tags of this Program.
        :type: list[str]
        """
        
        self._tags = tags

    @property
    def modified_by(self):
        """
        Gets the modified_by of this Program.


        :return: The modified_by of this Program.
        :rtype: AddressableEntityRef
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this Program.


        :param modified_by: The modified_by of this Program.
        :type: AddressableEntityRef
        """
        
        self._modified_by = modified_by

    @property
    def date_modified(self):
        """
        Gets the date_modified of this Program.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_modified of this Program.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this Program.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_modified: The date_modified of this Program.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def published_by(self):
        """
        Gets the published_by of this Program.


        :return: The published_by of this Program.
        :rtype: AddressableEntityRef
        """
        return self._published_by

    @published_by.setter
    def published_by(self, published_by):
        """
        Sets the published_by of this Program.


        :param published_by: The published_by of this Program.
        :type: AddressableEntityRef
        """
        
        self._published_by = published_by

    @property
    def date_published(self):
        """
        Gets the date_published of this Program.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_published of this Program.
        :rtype: datetime
        """
        return self._date_published

    @date_published.setter
    def date_published(self, date_published):
        """
        Sets the date_published of this Program.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_published: The date_published of this Program.
        :type: datetime
        """
        
        self._date_published = date_published

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Program.
        The URI for this object

        :return: The self_uri of this Program.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Program.
        The URI for this object

        :param self_uri: The self_uri of this Program.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class TtsEngineEntity(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        TtsEngineEntity - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'languages': 'list[str]',
            'output_formats': 'list[str]',
            'voices': 'list[TtsVoiceEntity]',
            'is_default': 'bool',
            'is_secure': 'bool',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'languages': 'languages',
            'output_formats': 'outputFormats',
            'voices': 'voices',
            'is_default': 'isDefault',
            'is_secure': 'isSecure',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._languages = None
        self._output_formats = None
        self._voices = None
        self._is_default = None
        self._is_secure = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this TtsEngineEntity.
        The globally unique identifier for the object.

        :return: The id of this TtsEngineEntity.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this TtsEngineEntity.
        The globally unique identifier for the object.

        :param id: The id of this TtsEngineEntity.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this TtsEngineEntity.


        :return: The name of this TtsEngineEntity.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TtsEngineEntity.


        :param name: The name of this TtsEngineEntity.
        :type: str
        """
        
        self._name = name

    @property
    def languages(self):
        """
        Gets the languages of this TtsEngineEntity.
        The set of languages the TTS engine supports

        :return: The languages of this TtsEngineEntity.
        :rtype: list[str]
        """
        return self._languages

    @languages.setter
    def languages(self, languages):
        """
        Sets the languages of this TtsEngineEntity.
        The set of languages the TTS engine supports

        :param languages: The languages of this TtsEngineEntity.
        :type: list[str]
        """
        
        self._languages = languages

    @property
    def output_formats(self):
        """
        Gets the output_formats of this TtsEngineEntity.
        The set of output formats the TTS engine can produce

        :return: The output_formats of this TtsEngineEntity.
        :rtype: list[str]
        """
        return self._output_formats

    @output_formats.setter
    def output_formats(self, output_formats):
        """
        Sets the output_formats of this TtsEngineEntity.
        The set of output formats the TTS engine can produce

        :param output_formats: The output_formats of this TtsEngineEntity.
        :type: list[str]
        """
        
        self._output_formats = output_formats

    @property
    def voices(self):
        """
        Gets the voices of this TtsEngineEntity.
        The set of voices the TTS engine supports

        :return: The voices of this TtsEngineEntity.
        :rtype: list[TtsVoiceEntity]
        """
        return self._voices

    @voices.setter
    def voices(self, voices):
        """
        Sets the voices of this TtsEngineEntity.
        The set of voices the TTS engine supports

        :param voices: The voices of this TtsEngineEntity.
        :type: list[TtsVoiceEntity]
        """
        
        self._voices = voices

    @property
    def is_default(self):
        """
        Gets the is_default of this TtsEngineEntity.
        The TTS engine is the global default engine

        :return: The is_default of this TtsEngineEntity.
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """
        Sets the is_default of this TtsEngineEntity.
        The TTS engine is the global default engine

        :param is_default: The is_default of this TtsEngineEntity.
        :type: bool
        """
        
        self._is_default = is_default

    @property
    def is_secure(self):
        """
        Gets the is_secure of this TtsEngineEntity.
        The TTS engine can be used in a secure call flow

        :return: The is_secure of this TtsEngineEntity.
        :rtype: bool
        """
        return self._is_secure

    @is_secure.setter
    def is_secure(self, is_secure):
        """
        Sets the is_secure of this TtsEngineEntity.
        The TTS engine can be used in a secure call flow

        :param is_secure: The is_secure of this TtsEngineEntity.
        :type: bool
        """
        
        self._is_secure = is_secure

    @property
    def self_uri(self):
        """
        Gets the self_uri of this TtsEngineEntity.
        The URI for this object

        :return: The self_uri of this TtsEngineEntity.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this TtsEngineEntity.
        The URI for this object

        :param self_uri: The self_uri of this TtsEngineEntity.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
ScriptsApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class ScriptsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def get_script(self, script_id, **kwargs):
        """
        Get a script
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_script(script_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str script_id: Script ID (required)
        :return: Script
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['script_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_script" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'script_id' is set
        if ('script_id' not in params) or (params['script_id'] is None):
            raise ValueError("Missing the required parameter `script_id` when calling `get_script`")


        resource_path = '/api/v2/scripts/{scriptId}'.replace('{format}', 'json')
        path_params = {}
        if 'script_id' in params:
            path_params['scriptId'] = params['script_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Script',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_script_page(self, script_id, page_id, **kwargs):
        """
        Get a page
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_script_page(script_id, page_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str script_id: Script ID (required)
        :param str page_id: Page ID (required)
        :param str script_data_version: Advanced usage - controls the data version of the script
        :return: Page
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['script_id', 'page_id', 'script_data_version']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_script_page" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'script_id' is set
        if ('script_id' not in params) or (params['script_id'] is None):
            raise ValueError("Missing the required parameter `script_id` when calling `get_script_page`")
        # verify the required parameter 'page_id' is set
        if ('page_id' not in params) or (params['page_id'] is None):
            raise ValueError("Missing the required parameter `page_id` when calling `get_script_page`")


        resource_path = '/api/v2/scripts/{scriptId}/pages/{pageId}'.replace('{format}', 'json')
        path_params = {}
        if 'script_id' in params:
            path_params['scriptId'] = params['script_id']
        if 'page_id' in params:
            path_params['pageId'] = params['page_id']

        query_params = {}
        if 'script_data_version' in params:
            query_params['scriptDataVersion'] = params['script_data_version']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Page',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_script_pages(self, script_id, **kwargs):
        """
        Get the list of pages
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_script_pages(script_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str script_id: Script ID (required)
        :param str script_data_version: Advanced usage - controls the data version of the script
        :return: list[Page]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['script_id', 'script_data_version']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_script_pages" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'script_id' is set
        if ('script_id' not in params) or (params['script_id'] is None):
            raise ValueError("Missing the required parameter `script_id` when calling `get_script_pages`")


        resource_path = '/api/v2/scripts/{scriptId}/pages'.replace('{format}', 'json')
        path_params = {}
        if 'script_id' in params:
            path_params['scriptId'] = params['script_id']

        query_params = {}
        if 'script_data_version' in params:
            query_params['scriptDataVersion'] = params['script_data_version']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='list[Page]',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_scripts(self, **kwargs):
        """
        Get the list of scripts
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_scripts(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int page_size: Page size
        :param int page_number: Page number
        :param str expand: Expand
        :param str name: Name filter
        :param str feature: Feature filter
        :param str flow_id: Secure flow id filter
        :param str sort_by: SortBy
        :param str sort_order: SortOrder
        :param str script_data_version: Advanced usage - controls the data version of the script
        :return: ScriptEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page_number', 'expand', 'name', 'feature', 'flow_id', 'sort_by', 'sort_order', 'script_data_version']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_scripts" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/scripts'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']
        if 'expand' in params:
            query_params['expand'] = params['expand']
        if 'name' in params:
            query_params['name'] = params['name']
        if 'feature' in params:
            query_params['feature'] = params['feature']
        if 'flow_id' in params:
            query_params['flowId'] = params['flow_id']
        if 'sort_by' in params:
            query_params['sortBy'] = params['sort_by']
        if 'sort_order' in params:
            query_params['sortOrder'] = params['sort_order']
        if 'script_data_version' in params:
            query_params['scriptDataVersion'] = params['script_data_version']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ScriptEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_scripts_published(self, **kwargs):
        """
        Get the published scripts.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_scripts_published(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int page_size: Page size
        :param int page_number: Page number
        :param str expand: Expand
        :param str name: Name filter
        :param str feature: Feature filter
        :param str flow_id: Secure flow id filter
        :param str script_data_version: Advanced usage - controls the data version of the script
        :return: ScriptEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page_number', 'expand', 'name', 'feature', 'flow_id', 'script_data_version']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_scripts_published" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/scripts/published'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']
        if 'expand' in params:
            query_params['expand'] = params['expand']
        if 'name' in params:
            query_params['name'] = params['name']
        if 'feature' in params:
            query_params['feature'] = params['feature']
        if 'flow_id' in params:
            query_params['flowId'] = params['flow_id']
        if 'script_data_version' in params:
            query_params['scriptDataVersion'] = params['script_data_version']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ScriptEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_scripts_published_script_id(self, script_id, **kwargs):
        """
        Get the published script.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_scripts_published_script_id(script_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str script_id: Script ID (required)
        :param str script_data_version: Advanced usage - controls the data version of the script
        :return: Script
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['script_id', 'script_data_version']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_scripts_published_script_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'script_id' is set
        if ('script_id' not in params) or (params['script_id'] is None):
            raise ValueError("Missing the required parameter `script_id` when calling `get_scripts_published_script_id`")


        resource_path = '/api/v2/scripts/published/{scriptId}'.replace('{format}', 'json')
        path_params = {}
        if 'script_id' in params:
            path_params['scriptId'] = params['script_id']

        query_params = {}
        if 'script_data_version' in params:
            query_params['scriptDataVersion'] = params['script_data_version']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Script',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_scripts_published_script_id_page(self, script_id, page_id, **kwargs):
        """
        Get the published page.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_scripts_published_script_id_page(script_id, page_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str script_id: Script ID (required)
        :param str page_id: Page ID (required)
        :param str script_data_version: Advanced usage - controls the data version of the script
        :return: Page
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['script_id', 'page_id', 'script_data_version']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_scripts_published_script_id_page" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'script_id' is set
        if ('script_id' not in params) or (params['script_id'] is None):
            raise ValueError("Missing the required parameter `script_id` when calling `get_scripts_published_script_id_page`")
        # verify the required parameter 'page_id' is set
        if ('page_id' not in params) or (params['page_id'] is None):
            raise ValueError("Missing the required parameter `page_id` when calling `get_scripts_published_script_id_page`")


        resource_path = '/api/v2/scripts/published/{scriptId}/pages/{pageId}'.replace('{format}', 'json')
        path_params = {}
        if 'script_id' in params:
            path_params['scriptId'] = params['script_id']
        if 'page_id' in params:
            path_params['pageId'] = params['page_id']

        query_params = {}
        if 'script_data_version' in params:
            query_params['scriptDataVersion'] = params['script_data_version']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Page',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_scripts_published_script_id_pages(self, script_id, **kwargs):
        """
        Get the list of published pages
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_scripts_published_script_id_pages(script_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str script_id: Script ID (required)
        :param str script_data_version: Advanced usage - controls the data version of the script
        :return: list[Page]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['script_id', 'script_data_version']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_scripts_published_script_id_pages" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'script_id' is set
        if ('script_id' not in params) or (params['script_id'] is None):
            raise ValueError("Missing the required parameter `script_id` when calling `get_scripts_published_script_id_pages`")


        resource_path = '/api/v2/scripts/published/{scriptId}/pages'.replace('{format}', 'json')
        path_params = {}
        if 'script_id' in params:
            path_params['scriptId'] = params['script_id']

        query_params = {}
        if 'script_data_version' in params:
            query_params['scriptDataVersion'] = params['script_data_version']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='list[Page]',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_scripts_published_script_id_variables(self, script_id, **kwargs):
        """
        Get the published variables
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_scripts_published_script_id_variables(script_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str script_id: Script ID (required)
        :param str input: input
        :param str output: output
        :param str type: type
        :param str script_data_version: Advanced usage - controls the data version of the script
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['script_id', 'input', 'output', 'type', 'script_data_version']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_scripts_published_script_id_variables" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'script_id' is set
        if ('script_id' not in params) or (params['script_id'] is None):
            raise ValueError("Missing the required parameter `script_id` when calling `get_scripts_published_script_id_variables`")


        resource_path = '/api/v2/scripts/published/{scriptId}/variables'.replace('{format}', 'json')
        path_params = {}
        if 'script_id' in params:
            path_params['scriptId'] = params['script_id']

        query_params = {}
        if 'input' in params:
            query_params['input'] = params['input']
        if 'output' in params:
            query_params['output'] = params['output']
        if 'type' in params:
            query_params['type'] = params['type']
        if 'script_data_version' in params:
            query_params['scriptDataVersion'] = params['script_data_version']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='object',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_scripts_upload_status(self, upload_id, **kwargs):
        """
        Get the upload status of an imported script
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_scripts_upload_status(upload_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str upload_id: Upload ID (required)
        :param bool long_poll: Enable longPolling endpoint
        :return: ImportScriptStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['upload_id', 'long_poll']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_scripts_upload_status" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'upload_id' is set
        if ('upload_id' not in params) or (params['upload_id'] is None):
            raise ValueError("Missing the required parameter `upload_id` when calling `get_scripts_upload_status`")


        resource_path = '/api/v2/scripts/uploads/{uploadId}/status'.replace('{format}', 'json')
        path_params = {}
        if 'upload_id' in params:
            path_params['uploadId'] = params['upload_id']

        query_params = {}
        if 'long_poll' in params:
            query_params['longPoll'] = params['long_poll']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ImportScriptStatusResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_script_export(self, script_id, **kwargs):
        """
        Export a script via download service.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_script_export(script_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str script_id: Script ID (required)
        :param ExportScriptRequest body: 
        :return: ExportScriptResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['script_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_script_export" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'script_id' is set
        if ('script_id' not in params) or (params['script_id'] is None):
            raise ValueError("Missing the required parameter `script_id` when calling `post_script_export`")


        resource_path = '/api/v2/scripts/{scriptId}/export'.replace('{format}', 'json')
        path_params = {}
        if 'script_id' in params:
            path_params['scriptId'] = params['script_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ExportScriptResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response



import sys
from datetime import datetime, date
from six import iteritems

def sanitize_for_serialization(obj):
    """
    Builds a JSON object ready for serialization.

    If obj is None, return None.
    If obj is str, int, float, bool, return directly.
    If obj is datetime.datetime, datetime.date
        convert to string in iso8601 format.
    If obj is list, sanitize each element in the list.
    If obj is dict, return the dict.
    If obj is swagger model, return the properties dict.

    :param obj: The data to serialize.
    :return: The serialized form of data.
    """
    types = (str, int, float, bool, tuple)
    if sys.version_info < (3,0):
        types = types + (unicode,)
    if isinstance(obj, type(None)):
        return None
    elif isinstance(obj, types):
        return obj
    elif isinstance(obj, list):
        return [sanitize_for_serialization(sub_obj)
                for sub_obj in obj]
    elif isinstance(obj, (datetime, date)):
        return obj.isoformat()
    else:
        if isinstance(obj, dict):
            obj_dict = obj
        else:
            # Convert model obj to dict except
            # attributes `swagger_types`, `attribute_map`
            # and attributes which value is not None.
            # Convert attribute name to json key in
            # model definition for request.
            obj_dict = {obj.attribute_map[attr]: getattr(obj, attr)
                        for attr, _ in iteritems(obj.swagger_types)
                        if getattr(obj, attr) is not None}

        return {key: sanitize_for_serialization(val)
                for key, val in iteritems(obj_dict)}



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class HistoricalAdherenceActuals(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        HistoricalAdherenceActuals - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'actual_activity_category': 'str',
            'start_offset_seconds': 'int',
            'end_offset_seconds': 'int'
        }

        self.attribute_map = {
            'actual_activity_category': 'actualActivityCategory',
            'start_offset_seconds': 'startOffsetSeconds',
            'end_offset_seconds': 'endOffsetSeconds'
        }

        self._actual_activity_category = None
        self._start_offset_seconds = None
        self._end_offset_seconds = None

    @property
    def actual_activity_category(self):
        """
        Gets the actual_activity_category of this HistoricalAdherenceActuals.
        Activity in which the user is actually engaged

        :return: The actual_activity_category of this HistoricalAdherenceActuals.
        :rtype: str
        """
        return self._actual_activity_category

    @actual_activity_category.setter
    def actual_activity_category(self, actual_activity_category):
        """
        Sets the actual_activity_category of this HistoricalAdherenceActuals.
        Activity in which the user is actually engaged

        :param actual_activity_category: The actual_activity_category of this HistoricalAdherenceActuals.
        :type: str
        """
        allowed_values = ["OnQueueWork", "Break", "Meal", "Meeting", "OffQueueWork", "TimeOff", "Training", "Unavailable", "Unscheduled"]
        if actual_activity_category.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for actual_activity_category -> " + actual_activity_category)
            self._actual_activity_category = "outdated_sdk_version"
        else:
            self._actual_activity_category = actual_activity_category

    @property
    def start_offset_seconds(self):
        """
        Gets the start_offset_seconds of this HistoricalAdherenceActuals.
        Actual start offset in seconds relative to query start time

        :return: The start_offset_seconds of this HistoricalAdherenceActuals.
        :rtype: int
        """
        return self._start_offset_seconds

    @start_offset_seconds.setter
    def start_offset_seconds(self, start_offset_seconds):
        """
        Sets the start_offset_seconds of this HistoricalAdherenceActuals.
        Actual start offset in seconds relative to query start time

        :param start_offset_seconds: The start_offset_seconds of this HistoricalAdherenceActuals.
        :type: int
        """
        
        self._start_offset_seconds = start_offset_seconds

    @property
    def end_offset_seconds(self):
        """
        Gets the end_offset_seconds of this HistoricalAdherenceActuals.
        Actual end offset in seconds relative to query start time

        :return: The end_offset_seconds of this HistoricalAdherenceActuals.
        :rtype: int
        """
        return self._end_offset_seconds

    @end_offset_seconds.setter
    def end_offset_seconds(self, end_offset_seconds):
        """
        Sets the end_offset_seconds of this HistoricalAdherenceActuals.
        Actual end offset in seconds relative to query start time

        :param end_offset_seconds: The end_offset_seconds of this HistoricalAdherenceActuals.
        :type: int
        """
        
        self._end_offset_seconds = end_offset_seconds

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class NumericRange(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        NumericRange - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'gt': 'float',
            'gte': 'float',
            'lt': 'float',
            'lte': 'float'
        }

        self.attribute_map = {
            'gt': 'gt',
            'gte': 'gte',
            'lt': 'lt',
            'lte': 'lte'
        }

        self._gt = None
        self._gte = None
        self._lt = None
        self._lte = None

    @property
    def gt(self):
        """
        Gets the gt of this NumericRange.
        Greater than

        :return: The gt of this NumericRange.
        :rtype: float
        """
        return self._gt

    @gt.setter
    def gt(self, gt):
        """
        Sets the gt of this NumericRange.
        Greater than

        :param gt: The gt of this NumericRange.
        :type: float
        """
        
        self._gt = gt

    @property
    def gte(self):
        """
        Gets the gte of this NumericRange.
        Greater than or equal to

        :return: The gte of this NumericRange.
        :rtype: float
        """
        return self._gte

    @gte.setter
    def gte(self, gte):
        """
        Sets the gte of this NumericRange.
        Greater than or equal to

        :param gte: The gte of this NumericRange.
        :type: float
        """
        
        self._gte = gte

    @property
    def lt(self):
        """
        Gets the lt of this NumericRange.
        Less than

        :return: The lt of this NumericRange.
        :rtype: float
        """
        return self._lt

    @lt.setter
    def lt(self, lt):
        """
        Sets the lt of this NumericRange.
        Less than

        :param lt: The lt of this NumericRange.
        :type: float
        """
        
        self._lt = lt

    @property
    def lte(self):
        """
        Gets the lte of this NumericRange.
        Less than or equal to

        :return: The lte of this NumericRange.
        :rtype: float
        """
        return self._lte

    @lte.setter
    def lte(self, lte):
        """
        Sets the lte of this NumericRange.
        Less than or equal to

        :param lte: The lte of this NumericRange.
        :type: float
        """
        
        self._lte = lte

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class QueueConversationVideoEventTopicMessage(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QueueConversationVideoEventTopicMessage - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'state': 'str',
            'held': 'bool',
            'error_info': 'QueueConversationVideoEventTopicErrorDetails',
            'provider': 'str',
            'script_id': 'str',
            'peer_id': 'str',
            'disconnect_type': 'str',
            'start_hold_time': 'datetime',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'to_address': 'QueueConversationVideoEventTopicAddress',
            'from_address': 'QueueConversationVideoEventTopicAddress',
            'messages': 'list[QueueConversationVideoEventTopicMessageDetails]',
            'messages_transcript_uri': 'str',
            'type': 'str',
            'recipient_country': 'str',
            'recipient_type': 'str',
            'journey_context': 'QueueConversationVideoEventTopicJourneyContext',
            'wrapup': 'QueueConversationVideoEventTopicWrapup',
            'after_call_work': 'QueueConversationVideoEventTopicAfterCallWork',
            'after_call_work_required': 'bool',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'id': 'id',
            'state': 'state',
            'held': 'held',
            'error_info': 'errorInfo',
            'provider': 'provider',
            'script_id': 'scriptId',
            'peer_id': 'peerId',
            'disconnect_type': 'disconnectType',
            'start_hold_time': 'startHoldTime',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'to_address': 'toAddress',
            'from_address': 'fromAddress',
            'messages': 'messages',
            'messages_transcript_uri': 'messagesTranscriptUri',
            'type': 'type',
            'recipient_country': 'recipientCountry',
            'recipient_type': 'recipientType',
            'journey_context': 'journeyContext',
            'wrapup': 'wrapup',
            'after_call_work': 'afterCallWork',
            'after_call_work_required': 'afterCallWorkRequired',
            'additional_properties': 'additionalProperties'
        }

        self._id = None
        self._state = None
        self._held = None
        self._error_info = None
        self._provider = None
        self._script_id = None
        self._peer_id = None
        self._disconnect_type = None
        self._start_hold_time = None
        self._connected_time = None
        self._disconnected_time = None
        self._to_address = None
        self._from_address = None
        self._messages = None
        self._messages_transcript_uri = None
        self._type = None
        self._recipient_country = None
        self._recipient_type = None
        self._journey_context = None
        self._wrapup = None
        self._after_call_work = None
        self._after_call_work_required = None
        self._additional_properties = None

    @property
    def id(self):
        """
        Gets the id of this QueueConversationVideoEventTopicMessage.


        :return: The id of this QueueConversationVideoEventTopicMessage.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QueueConversationVideoEventTopicMessage.


        :param id: The id of this QueueConversationVideoEventTopicMessage.
        :type: str
        """
        
        self._id = id

    @property
    def state(self):
        """
        Gets the state of this QueueConversationVideoEventTopicMessage.


        :return: The state of this QueueConversationVideoEventTopicMessage.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this QueueConversationVideoEventTopicMessage.


        :param state: The state of this QueueConversationVideoEventTopicMessage.
        :type: str
        """
        allowed_values = ["ALERTING", "CONNECTED", "DISCONNECTED"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def held(self):
        """
        Gets the held of this QueueConversationVideoEventTopicMessage.


        :return: The held of this QueueConversationVideoEventTopicMessage.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this QueueConversationVideoEventTopicMessage.


        :param held: The held of this QueueConversationVideoEventTopicMessage.
        :type: bool
        """
        
        self._held = held

    @property
    def error_info(self):
        """
        Gets the error_info of this QueueConversationVideoEventTopicMessage.


        :return: The error_info of this QueueConversationVideoEventTopicMessage.
        :rtype: QueueConversationVideoEventTopicErrorDetails
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this QueueConversationVideoEventTopicMessage.


        :param error_info: The error_info of this QueueConversationVideoEventTopicMessage.
        :type: QueueConversationVideoEventTopicErrorDetails
        """
        
        self._error_info = error_info

    @property
    def provider(self):
        """
        Gets the provider of this QueueConversationVideoEventTopicMessage.


        :return: The provider of this QueueConversationVideoEventTopicMessage.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this QueueConversationVideoEventTopicMessage.


        :param provider: The provider of this QueueConversationVideoEventTopicMessage.
        :type: str
        """
        
        self._provider = provider

    @property
    def script_id(self):
        """
        Gets the script_id of this QueueConversationVideoEventTopicMessage.


        :return: The script_id of this QueueConversationVideoEventTopicMessage.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """
        Sets the script_id of this QueueConversationVideoEventTopicMessage.


        :param script_id: The script_id of this QueueConversationVideoEventTopicMessage.
        :type: str
        """
        
        self._script_id = script_id

    @property
    def peer_id(self):
        """
        Gets the peer_id of this QueueConversationVideoEventTopicMessage.


        :return: The peer_id of this QueueConversationVideoEventTopicMessage.
        :rtype: str
        """
        return self._peer_id

    @peer_id.setter
    def peer_id(self, peer_id):
        """
        Sets the peer_id of this QueueConversationVideoEventTopicMessage.


        :param peer_id: The peer_id of this QueueConversationVideoEventTopicMessage.
        :type: str
        """
        
        self._peer_id = peer_id

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this QueueConversationVideoEventTopicMessage.


        :return: The disconnect_type of this QueueConversationVideoEventTopicMessage.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this QueueConversationVideoEventTopicMessage.


        :param disconnect_type: The disconnect_type of this QueueConversationVideoEventTopicMessage.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TIMEOUT", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_FORWARD", "TRANSFER_NOANSWER", "TRANSFER_NOTAVAILABLE", "TRANSPORT_FAILURE", "ERROR", "PEER", "OTHER", "SPAM", "UNCALLABLE"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this QueueConversationVideoEventTopicMessage.


        :return: The start_hold_time of this QueueConversationVideoEventTopicMessage.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this QueueConversationVideoEventTopicMessage.


        :param start_hold_time: The start_hold_time of this QueueConversationVideoEventTopicMessage.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this QueueConversationVideoEventTopicMessage.


        :return: The connected_time of this QueueConversationVideoEventTopicMessage.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this QueueConversationVideoEventTopicMessage.


        :param connected_time: The connected_time of this QueueConversationVideoEventTopicMessage.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this QueueConversationVideoEventTopicMessage.


        :return: The disconnected_time of this QueueConversationVideoEventTopicMessage.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this QueueConversationVideoEventTopicMessage.


        :param disconnected_time: The disconnected_time of this QueueConversationVideoEventTopicMessage.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def to_address(self):
        """
        Gets the to_address of this QueueConversationVideoEventTopicMessage.


        :return: The to_address of this QueueConversationVideoEventTopicMessage.
        :rtype: QueueConversationVideoEventTopicAddress
        """
        return self._to_address

    @to_address.setter
    def to_address(self, to_address):
        """
        Sets the to_address of this QueueConversationVideoEventTopicMessage.


        :param to_address: The to_address of this QueueConversationVideoEventTopicMessage.
        :type: QueueConversationVideoEventTopicAddress
        """
        
        self._to_address = to_address

    @property
    def from_address(self):
        """
        Gets the from_address of this QueueConversationVideoEventTopicMessage.


        :return: The from_address of this QueueConversationVideoEventTopicMessage.
        :rtype: QueueConversationVideoEventTopicAddress
        """
        return self._from_address

    @from_address.setter
    def from_address(self, from_address):
        """
        Sets the from_address of this QueueConversationVideoEventTopicMessage.


        :param from_address: The from_address of this QueueConversationVideoEventTopicMessage.
        :type: QueueConversationVideoEventTopicAddress
        """
        
        self._from_address = from_address

    @property
    def messages(self):
        """
        Gets the messages of this QueueConversationVideoEventTopicMessage.


        :return: The messages of this QueueConversationVideoEventTopicMessage.
        :rtype: list[QueueConversationVideoEventTopicMessageDetails]
        """
        return self._messages

    @messages.setter
    def messages(self, messages):
        """
        Sets the messages of this QueueConversationVideoEventTopicMessage.


        :param messages: The messages of this QueueConversationVideoEventTopicMessage.
        :type: list[QueueConversationVideoEventTopicMessageDetails]
        """
        
        self._messages = messages

    @property
    def messages_transcript_uri(self):
        """
        Gets the messages_transcript_uri of this QueueConversationVideoEventTopicMessage.


        :return: The messages_transcript_uri of this QueueConversationVideoEventTopicMessage.
        :rtype: str
        """
        return self._messages_transcript_uri

    @messages_transcript_uri.setter
    def messages_transcript_uri(self, messages_transcript_uri):
        """
        Sets the messages_transcript_uri of this QueueConversationVideoEventTopicMessage.


        :param messages_transcript_uri: The messages_transcript_uri of this QueueConversationVideoEventTopicMessage.
        :type: str
        """
        
        self._messages_transcript_uri = messages_transcript_uri

    @property
    def type(self):
        """
        Gets the type of this QueueConversationVideoEventTopicMessage.


        :return: The type of this QueueConversationVideoEventTopicMessage.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this QueueConversationVideoEventTopicMessage.


        :param type: The type of this QueueConversationVideoEventTopicMessage.
        :type: str
        """
        allowed_values = ["UNKNOWN", "SMS", "TWITTER", "FACEBOOK", "LINE", "VIBER", "WECHAT", "WHATSAPP", "TELEGRAM", "KAKAO", "WEBMESSAGING"]
        if type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for type -> " + type)
            self._type = "outdated_sdk_version"
        else:
            self._type = type

    @property
    def recipient_country(self):
        """
        Gets the recipient_country of this QueueConversationVideoEventTopicMessage.


        :return: The recipient_country of this QueueConversationVideoEventTopicMessage.
        :rtype: str
        """
        return self._recipient_country

    @recipient_country.setter
    def recipient_country(self, recipient_country):
        """
        Sets the recipient_country of this QueueConversationVideoEventTopicMessage.


        :param recipient_country: The recipient_country of this QueueConversationVideoEventTopicMessage.
        :type: str
        """
        
        self._recipient_country = recipient_country

    @property
    def recipient_type(self):
        """
        Gets the recipient_type of this QueueConversationVideoEventTopicMessage.


        :return: The recipient_type of this QueueConversationVideoEventTopicMessage.
        :rtype: str
        """
        return self._recipient_type

    @recipient_type.setter
    def recipient_type(self, recipient_type):
        """
        Sets the recipient_type of this QueueConversationVideoEventTopicMessage.


        :param recipient_type: The recipient_type of this QueueConversationVideoEventTopicMessage.
        :type: str
        """
        
        self._recipient_type = recipient_type

    @property
    def journey_context(self):
        """
        Gets the journey_context of this QueueConversationVideoEventTopicMessage.


        :return: The journey_context of this QueueConversationVideoEventTopicMessage.
        :rtype: QueueConversationVideoEventTopicJourneyContext
        """
        return self._journey_context

    @journey_context.setter
    def journey_context(self, journey_context):
        """
        Sets the journey_context of this QueueConversationVideoEventTopicMessage.


        :param journey_context: The journey_context of this QueueConversationVideoEventTopicMessage.
        :type: QueueConversationVideoEventTopicJourneyContext
        """
        
        self._journey_context = journey_context

    @property
    def wrapup(self):
        """
        Gets the wrapup of this QueueConversationVideoEventTopicMessage.


        :return: The wrapup of this QueueConversationVideoEventTopicMessage.
        :rtype: QueueConversationVideoEventTopicWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this QueueConversationVideoEventTopicMessage.


        :param wrapup: The wrapup of this QueueConversationVideoEventTopicMessage.
        :type: QueueConversationVideoEventTopicWrapup
        """
        
        self._wrapup = wrapup

    @property
    def after_call_work(self):
        """
        Gets the after_call_work of this QueueConversationVideoEventTopicMessage.


        :return: The after_call_work of this QueueConversationVideoEventTopicMessage.
        :rtype: QueueConversationVideoEventTopicAfterCallWork
        """
        return self._after_call_work

    @after_call_work.setter
    def after_call_work(self, after_call_work):
        """
        Sets the after_call_work of this QueueConversationVideoEventTopicMessage.


        :param after_call_work: The after_call_work of this QueueConversationVideoEventTopicMessage.
        :type: QueueConversationVideoEventTopicAfterCallWork
        """
        
        self._after_call_work = after_call_work

    @property
    def after_call_work_required(self):
        """
        Gets the after_call_work_required of this QueueConversationVideoEventTopicMessage.


        :return: The after_call_work_required of this QueueConversationVideoEventTopicMessage.
        :rtype: bool
        """
        return self._after_call_work_required

    @after_call_work_required.setter
    def after_call_work_required(self, after_call_work_required):
        """
        Sets the after_call_work_required of this QueueConversationVideoEventTopicMessage.


        :param after_call_work_required: The after_call_work_required of this QueueConversationVideoEventTopicMessage.
        :type: bool
        """
        
        self._after_call_work_required = after_call_work_required

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this QueueConversationVideoEventTopicMessage.


        :return: The additional_properties of this QueueConversationVideoEventTopicMessage.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this QueueConversationVideoEventTopicMessage.


        :param additional_properties: The additional_properties of this QueueConversationVideoEventTopicMessage.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class MessageMediaData(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        MessageMediaData - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'url': 'str',
            'media_type': 'str',
            'content_length_bytes': 'int',
            'upload_url': 'str',
            'status': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'url': 'url',
            'media_type': 'mediaType',
            'content_length_bytes': 'contentLengthBytes',
            'upload_url': 'uploadUrl',
            'status': 'status',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._url = None
        self._media_type = None
        self._content_length_bytes = None
        self._upload_url = None
        self._status = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this MessageMediaData.
        The globally unique identifier for the object.

        :return: The id of this MessageMediaData.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this MessageMediaData.
        The globally unique identifier for the object.

        :param id: The id of this MessageMediaData.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this MessageMediaData.


        :return: The name of this MessageMediaData.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this MessageMediaData.


        :param name: The name of this MessageMediaData.
        :type: str
        """
        
        self._name = name

    @property
    def url(self):
        """
        Gets the url of this MessageMediaData.
        The location of the media, useful for retrieving it

        :return: The url of this MessageMediaData.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """
        Sets the url of this MessageMediaData.
        The location of the media, useful for retrieving it

        :param url: The url of this MessageMediaData.
        :type: str
        """
        
        self._url = url

    @property
    def media_type(self):
        """
        Gets the media_type of this MessageMediaData.
        The detected internet media type of the the media object.  If null then the media type should be dictated by the url.

        :return: The media_type of this MessageMediaData.
        :rtype: str
        """
        return self._media_type

    @media_type.setter
    def media_type(self, media_type):
        """
        Sets the media_type of this MessageMediaData.
        The detected internet media type of the the media object.  If null then the media type should be dictated by the url.

        :param media_type: The media_type of this MessageMediaData.
        :type: str
        """
        
        self._media_type = media_type

    @property
    def content_length_bytes(self):
        """
        Gets the content_length_bytes of this MessageMediaData.
        The optional content length of the the media object, in bytes.

        :return: The content_length_bytes of this MessageMediaData.
        :rtype: int
        """
        return self._content_length_bytes

    @content_length_bytes.setter
    def content_length_bytes(self, content_length_bytes):
        """
        Sets the content_length_bytes of this MessageMediaData.
        The optional content length of the the media object, in bytes.

        :param content_length_bytes: The content_length_bytes of this MessageMediaData.
        :type: int
        """
        
        self._content_length_bytes = content_length_bytes

    @property
    def upload_url(self):
        """
        Gets the upload_url of this MessageMediaData.
        The URL returned to upload an attachment

        :return: The upload_url of this MessageMediaData.
        :rtype: str
        """
        return self._upload_url

    @upload_url.setter
    def upload_url(self, upload_url):
        """
        Sets the upload_url of this MessageMediaData.
        The URL returned to upload an attachment

        :param upload_url: The upload_url of this MessageMediaData.
        :type: str
        """
        
        self._upload_url = upload_url

    @property
    def status(self):
        """
        Gets the status of this MessageMediaData.
        The status of the media, indicates if the media is in the process of uploading. If the upload fails, the media becomes invalid

        :return: The status of this MessageMediaData.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this MessageMediaData.
        The status of the media, indicates if the media is in the process of uploading. If the upload fails, the media becomes invalid

        :param status: The status of this MessageMediaData.
        :type: str
        """
        allowed_values = ["uploading", "valid", "invalid"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def self_uri(self):
        """
        Gets the self_uri of this MessageMediaData.
        The URI for this object

        :return: The self_uri of this MessageMediaData.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this MessageMediaData.
        The URI for this object

        :param self_uri: The self_uri of this MessageMediaData.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class LocalEncryptionKeyRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        LocalEncryptionKeyRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'config_id': 'str',
            'public_key': 'str',
            'keypair_id': 'str'
        }

        self.attribute_map = {
            'config_id': 'configId',
            'public_key': 'publicKey',
            'keypair_id': 'keypairId'
        }

        self._config_id = None
        self._public_key = None
        self._keypair_id = None

    @property
    def config_id(self):
        """
        Gets the config_id of this LocalEncryptionKeyRequest.
        The local configuration id that contains metadata on private local service

        :return: The config_id of this LocalEncryptionKeyRequest.
        :rtype: str
        """
        return self._config_id

    @config_id.setter
    def config_id(self, config_id):
        """
        Sets the config_id of this LocalEncryptionKeyRequest.
        The local configuration id that contains metadata on private local service

        :param config_id: The config_id of this LocalEncryptionKeyRequest.
        :type: str
        """
        
        self._config_id = config_id

    @property
    def public_key(self):
        """
        Gets the public_key of this LocalEncryptionKeyRequest.
        Base 64 encoded public key, generated by the local service.

        :return: The public_key of this LocalEncryptionKeyRequest.
        :rtype: str
        """
        return self._public_key

    @public_key.setter
    def public_key(self, public_key):
        """
        Sets the public_key of this LocalEncryptionKeyRequest.
        Base 64 encoded public key, generated by the local service.

        :param public_key: The public_key of this LocalEncryptionKeyRequest.
        :type: str
        """
        
        self._public_key = public_key

    @property
    def keypair_id(self):
        """
        Gets the keypair_id of this LocalEncryptionKeyRequest.
        The key pair id from the local service.

        :return: The keypair_id of this LocalEncryptionKeyRequest.
        :rtype: str
        """
        return self._keypair_id

    @keypair_id.setter
    def keypair_id(self, keypair_id):
        """
        Sets the keypair_id of this LocalEncryptionKeyRequest.
        The key pair id from the local service.

        :param keypair_id: The keypair_id of this LocalEncryptionKeyRequest.
        :type: str
        """
        
        self._keypair_id = keypair_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ActionMap(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ActionMap - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'version': 'int',
            'is_active': 'bool',
            'display_name': 'str',
            'trigger_with_segments': 'list[str]',
            'trigger_with_event_conditions': 'list[EventCondition]',
            'trigger_with_outcome_probability_conditions': 'list[OutcomeProbabilityCondition]',
            'page_url_conditions': 'list[UrlCondition]',
            'activation': 'Activation',
            'weight': 'int',
            'action': 'ActionMapAction',
            'action_map_schedule_groups': 'ActionMapScheduleGroups',
            'ignore_frequency_cap': 'bool',
            'self_uri': 'str',
            'created_date': 'datetime',
            'modified_date': 'datetime',
            'start_date': 'datetime',
            'end_date': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'version': 'version',
            'is_active': 'isActive',
            'display_name': 'displayName',
            'trigger_with_segments': 'triggerWithSegments',
            'trigger_with_event_conditions': 'triggerWithEventConditions',
            'trigger_with_outcome_probability_conditions': 'triggerWithOutcomeProbabilityConditions',
            'page_url_conditions': 'pageUrlConditions',
            'activation': 'activation',
            'weight': 'weight',
            'action': 'action',
            'action_map_schedule_groups': 'actionMapScheduleGroups',
            'ignore_frequency_cap': 'ignoreFrequencyCap',
            'self_uri': 'selfUri',
            'created_date': 'createdDate',
            'modified_date': 'modifiedDate',
            'start_date': 'startDate',
            'end_date': 'endDate'
        }

        self._id = None
        self._version = None
        self._is_active = None
        self._display_name = None
        self._trigger_with_segments = None
        self._trigger_with_event_conditions = None
        self._trigger_with_outcome_probability_conditions = None
        self._page_url_conditions = None
        self._activation = None
        self._weight = None
        self._action = None
        self._action_map_schedule_groups = None
        self._ignore_frequency_cap = None
        self._self_uri = None
        self._created_date = None
        self._modified_date = None
        self._start_date = None
        self._end_date = None

    @property
    def id(self):
        """
        Gets the id of this ActionMap.
        The globally unique identifier for the object.

        :return: The id of this ActionMap.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ActionMap.
        The globally unique identifier for the object.

        :param id: The id of this ActionMap.
        :type: str
        """
        
        self._id = id

    @property
    def version(self):
        """
        Gets the version of this ActionMap.
        The version of the action map.

        :return: The version of this ActionMap.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this ActionMap.
        The version of the action map.

        :param version: The version of this ActionMap.
        :type: int
        """
        
        self._version = version

    @property
    def is_active(self):
        """
        Gets the is_active of this ActionMap.
        Whether the action map is active.

        :return: The is_active of this ActionMap.
        :rtype: bool
        """
        return self._is_active

    @is_active.setter
    def is_active(self, is_active):
        """
        Sets the is_active of this ActionMap.
        Whether the action map is active.

        :param is_active: The is_active of this ActionMap.
        :type: bool
        """
        
        self._is_active = is_active

    @property
    def display_name(self):
        """
        Gets the display_name of this ActionMap.
        Display name of the action map.

        :return: The display_name of this ActionMap.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ActionMap.
        Display name of the action map.

        :param display_name: The display_name of this ActionMap.
        :type: str
        """
        
        self._display_name = display_name

    @property
    def trigger_with_segments(self):
        """
        Gets the trigger_with_segments of this ActionMap.
        Trigger action map if any segment in the list is assigned to a given customer.

        :return: The trigger_with_segments of this ActionMap.
        :rtype: list[str]
        """
        return self._trigger_with_segments

    @trigger_with_segments.setter
    def trigger_with_segments(self, trigger_with_segments):
        """
        Sets the trigger_with_segments of this ActionMap.
        Trigger action map if any segment in the list is assigned to a given customer.

        :param trigger_with_segments: The trigger_with_segments of this ActionMap.
        :type: list[str]
        """
        
        self._trigger_with_segments = trigger_with_segments

    @property
    def trigger_with_event_conditions(self):
        """
        Gets the trigger_with_event_conditions of this ActionMap.
        List of event conditions that must be satisfied to trigger the action map.

        :return: The trigger_with_event_conditions of this ActionMap.
        :rtype: list[EventCondition]
        """
        return self._trigger_with_event_conditions

    @trigger_with_event_conditions.setter
    def trigger_with_event_conditions(self, trigger_with_event_conditions):
        """
        Sets the trigger_with_event_conditions of this ActionMap.
        List of event conditions that must be satisfied to trigger the action map.

        :param trigger_with_event_conditions: The trigger_with_event_conditions of this ActionMap.
        :type: list[EventCondition]
        """
        
        self._trigger_with_event_conditions = trigger_with_event_conditions

    @property
    def trigger_with_outcome_probability_conditions(self):
        """
        Gets the trigger_with_outcome_probability_conditions of this ActionMap.
        Probability conditions for outcomes that must be satisfied to trigger the action map.

        :return: The trigger_with_outcome_probability_conditions of this ActionMap.
        :rtype: list[OutcomeProbabilityCondition]
        """
        return self._trigger_with_outcome_probability_conditions

    @trigger_with_outcome_probability_conditions.setter
    def trigger_with_outcome_probability_conditions(self, trigger_with_outcome_probability_conditions):
        """
        Sets the trigger_with_outcome_probability_conditions of this ActionMap.
        Probability conditions for outcomes that must be satisfied to trigger the action map.

        :param trigger_with_outcome_probability_conditions: The trigger_with_outcome_probability_conditions of this ActionMap.
        :type: list[OutcomeProbabilityCondition]
        """
        
        self._trigger_with_outcome_probability_conditions = trigger_with_outcome_probability_conditions

    @property
    def page_url_conditions(self):
        """
        Gets the page_url_conditions of this ActionMap.
        URL conditions that a page must match for web actions to be displayable.

        :return: The page_url_conditions of this ActionMap.
        :rtype: list[UrlCondition]
        """
        return self._page_url_conditions

    @page_url_conditions.setter
    def page_url_conditions(self, page_url_conditions):
        """
        Sets the page_url_conditions of this ActionMap.
        URL conditions that a page must match for web actions to be displayable.

        :param page_url_conditions: The page_url_conditions of this ActionMap.
        :type: list[UrlCondition]
        """
        
        self._page_url_conditions = page_url_conditions

    @property
    def activation(self):
        """
        Gets the activation of this ActionMap.
        Type of activation.

        :return: The activation of this ActionMap.
        :rtype: Activation
        """
        return self._activation

    @activation.setter
    def activation(self, activation):
        """
        Sets the activation of this ActionMap.
        Type of activation.

        :param activation: The activation of this ActionMap.
        :type: Activation
        """
        
        self._activation = activation

    @property
    def weight(self):
        """
        Gets the weight of this ActionMap.
        Weight of the action map with higher number denoting higher weight.

        :return: The weight of this ActionMap.
        :rtype: int
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """
        Sets the weight of this ActionMap.
        Weight of the action map with higher number denoting higher weight.

        :param weight: The weight of this ActionMap.
        :type: int
        """
        
        self._weight = weight

    @property
    def action(self):
        """
        Gets the action of this ActionMap.
        The action that will be executed if this action map is triggered.

        :return: The action of this ActionMap.
        :rtype: ActionMapAction
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this ActionMap.
        The action that will be executed if this action map is triggered.

        :param action: The action of this ActionMap.
        :type: ActionMapAction
        """
        
        self._action = action

    @property
    def action_map_schedule_groups(self):
        """
        Gets the action_map_schedule_groups of this ActionMap.
        The action map's associated schedule groups.

        :return: The action_map_schedule_groups of this ActionMap.
        :rtype: ActionMapScheduleGroups
        """
        return self._action_map_schedule_groups

    @action_map_schedule_groups.setter
    def action_map_schedule_groups(self, action_map_schedule_groups):
        """
        Sets the action_map_schedule_groups of this ActionMap.
        The action map's associated schedule groups.

        :param action_map_schedule_groups: The action_map_schedule_groups of this ActionMap.
        :type: ActionMapScheduleGroups
        """
        
        self._action_map_schedule_groups = action_map_schedule_groups

    @property
    def ignore_frequency_cap(self):
        """
        Gets the ignore_frequency_cap of this ActionMap.
        Override organization-level frequency cap and always offer web engagements from this action map.

        :return: The ignore_frequency_cap of this ActionMap.
        :rtype: bool
        """
        return self._ignore_frequency_cap

    @ignore_frequency_cap.setter
    def ignore_frequency_cap(self, ignore_frequency_cap):
        """
        Sets the ignore_frequency_cap of this ActionMap.
        Override organization-level frequency cap and always offer web engagements from this action map.

        :param ignore_frequency_cap: The ignore_frequency_cap of this ActionMap.
        :type: bool
        """
        
        self._ignore_frequency_cap = ignore_frequency_cap

    @property
    def self_uri(self):
        """
        Gets the self_uri of this ActionMap.
        The URI for this object

        :return: The self_uri of this ActionMap.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this ActionMap.
        The URI for this object

        :param self_uri: The self_uri of this ActionMap.
        :type: str
        """
        
        self._self_uri = self_uri

    @property
    def created_date(self):
        """
        Gets the created_date of this ActionMap.
        Timestamp indicating when the action map was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The created_date of this ActionMap.
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this ActionMap.
        Timestamp indicating when the action map was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param created_date: The created_date of this ActionMap.
        :type: datetime
        """
        
        self._created_date = created_date

    @property
    def modified_date(self):
        """
        Gets the modified_date of this ActionMap.
        Timestamp indicating when the action map was last updated. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The modified_date of this ActionMap.
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this ActionMap.
        Timestamp indicating when the action map was last updated. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param modified_date: The modified_date of this ActionMap.
        :type: datetime
        """
        
        self._modified_date = modified_date

    @property
    def start_date(self):
        """
        Gets the start_date of this ActionMap.
        Timestamp at which the action map is scheduled to start firing. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_date of this ActionMap.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this ActionMap.
        Timestamp at which the action map is scheduled to start firing. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_date: The start_date of this ActionMap.
        :type: datetime
        """
        
        self._start_date = start_date

    @property
    def end_date(self):
        """
        Gets the end_date of this ActionMap.
        Timestamp at which the action map is scheduled to stop firing. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The end_date of this ActionMap.
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this ActionMap.
        Timestamp at which the action map is scheduled to stop firing. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param end_date: The end_date of this ActionMap.
        :type: datetime
        """
        
        self._end_date = end_date

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class TestExecutionOperationResult(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        TestExecutionOperationResult - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'step': 'int',
            'name': 'str',
            'success': 'bool',
            'result': 'object',
            'error': 'ErrorBody'
        }

        self.attribute_map = {
            'step': 'step',
            'name': 'name',
            'success': 'success',
            'result': 'result',
            'error': 'error'
        }

        self._step = None
        self._name = None
        self._success = None
        self._result = None
        self._error = None

    @property
    def step(self):
        """
        Gets the step of this TestExecutionOperationResult.
        The step number to indicate the order in which the operation was performed

        :return: The step of this TestExecutionOperationResult.
        :rtype: int
        """
        return self._step

    @step.setter
    def step(self, step):
        """
        Sets the step of this TestExecutionOperationResult.
        The step number to indicate the order in which the operation was performed

        :param step: The step of this TestExecutionOperationResult.
        :type: int
        """
        
        self._step = step

    @property
    def name(self):
        """
        Gets the name of this TestExecutionOperationResult.
        Name of the operation performed

        :return: The name of this TestExecutionOperationResult.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TestExecutionOperationResult.
        Name of the operation performed

        :param name: The name of this TestExecutionOperationResult.
        :type: str
        """
        
        self._name = name

    @property
    def success(self):
        """
        Gets the success of this TestExecutionOperationResult.
        Indicated whether or not the operation was successful

        :return: The success of this TestExecutionOperationResult.
        :rtype: bool
        """
        return self._success

    @success.setter
    def success(self, success):
        """
        Sets the success of this TestExecutionOperationResult.
        Indicated whether or not the operation was successful

        :param success: The success of this TestExecutionOperationResult.
        :type: bool
        """
        
        self._success = success

    @property
    def result(self):
        """
        Gets the result of this TestExecutionOperationResult.
        The result of the operation

        :return: The result of this TestExecutionOperationResult.
        :rtype: object
        """
        return self._result

    @result.setter
    def result(self, result):
        """
        Sets the result of this TestExecutionOperationResult.
        The result of the operation

        :param result: The result of this TestExecutionOperationResult.
        :type: object
        """
        
        self._result = result

    @property
    def error(self):
        """
        Gets the error of this TestExecutionOperationResult.
        Error that occurred during the operation

        :return: The error of this TestExecutionOperationResult.
        :rtype: ErrorBody
        """
        return self._error

    @error.setter
    def error(self, error):
        """
        Sets the error of this TestExecutionOperationResult.
        Error that occurred during the operation

        :param error: The error of this TestExecutionOperationResult.
        :type: ErrorBody
        """
        
        self._error = error

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ConversationCallbackEventTopicCallbackMediaParticipant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ConversationCallbackEventTopicCallbackMediaParticipant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'address': 'str',
            'start_time': 'datetime',
            'connected_time': 'datetime',
            'end_time': 'datetime',
            'start_hold_time': 'datetime',
            'purpose': 'str',
            'state': 'str',
            'direction': 'str',
            'disconnect_type': 'str',
            'held': 'bool',
            'wrapup_required': 'bool',
            'wrapup_prompt': 'str',
            'user': 'ConversationCallbackEventTopicUriReference',
            'queue': 'ConversationCallbackEventTopicUriReference',
            'team': 'ConversationCallbackEventTopicUriReference',
            'attributes': 'dict(str, str)',
            'error_info': 'ConversationCallbackEventTopicErrorBody',
            'script': 'ConversationCallbackEventTopicUriReference',
            'wrapup_timeout_ms': 'int',
            'wrapup_skipped': 'bool',
            'alerting_timeout_ms': 'int',
            'provider': 'str',
            'external_contact': 'ConversationCallbackEventTopicUriReference',
            'external_organization': 'ConversationCallbackEventTopicUriReference',
            'wrapup': 'ConversationCallbackEventTopicWrapup',
            'conversation_routing_data': 'ConversationCallbackEventTopicConversationRoutingData',
            'peer': 'str',
            'screen_recording_state': 'str',
            'flagged_reason': 'str',
            'journey_context': 'ConversationCallbackEventTopicJourneyContext',
            'start_acw_time': 'datetime',
            'end_acw_time': 'datetime',
            'outbound_preview': 'ConversationCallbackEventTopicDialerPreview',
            'voicemail': 'ConversationCallbackEventTopicVoicemail',
            'callback_numbers': 'list[str]',
            'callback_user_name': 'str',
            'skip_enabled': 'bool',
            'external_campaign': 'bool',
            'timeout_seconds': 'int',
            'callback_scheduled_time': 'datetime',
            'automated_callback_config_id': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'address': 'address',
            'start_time': 'startTime',
            'connected_time': 'connectedTime',
            'end_time': 'endTime',
            'start_hold_time': 'startHoldTime',
            'purpose': 'purpose',
            'state': 'state',
            'direction': 'direction',
            'disconnect_type': 'disconnectType',
            'held': 'held',
            'wrapup_required': 'wrapupRequired',
            'wrapup_prompt': 'wrapupPrompt',
            'user': 'user',
            'queue': 'queue',
            'team': 'team',
            'attributes': 'attributes',
            'error_info': 'errorInfo',
            'script': 'script',
            'wrapup_timeout_ms': 'wrapupTimeoutMs',
            'wrapup_skipped': 'wrapupSkipped',
            'alerting_timeout_ms': 'alertingTimeoutMs',
            'provider': 'provider',
            'external_contact': 'externalContact',
            'external_organization': 'externalOrganization',
            'wrapup': 'wrapup',
            'conversation_routing_data': 'conversationRoutingData',
            'peer': 'peer',
            'screen_recording_state': 'screenRecordingState',
            'flagged_reason': 'flaggedReason',
            'journey_context': 'journeyContext',
            'start_acw_time': 'startAcwTime',
            'end_acw_time': 'endAcwTime',
            'outbound_preview': 'outboundPreview',
            'voicemail': 'voicemail',
            'callback_numbers': 'callbackNumbers',
            'callback_user_name': 'callbackUserName',
            'skip_enabled': 'skipEnabled',
            'external_campaign': 'externalCampaign',
            'timeout_seconds': 'timeoutSeconds',
            'callback_scheduled_time': 'callbackScheduledTime',
            'automated_callback_config_id': 'automatedCallbackConfigId'
        }

        self._id = None
        self._name = None
        self._address = None
        self._start_time = None
        self._connected_time = None
        self._end_time = None
        self._start_hold_time = None
        self._purpose = None
        self._state = None
        self._direction = None
        self._disconnect_type = None
        self._held = None
        self._wrapup_required = None
        self._wrapup_prompt = None
        self._user = None
        self._queue = None
        self._team = None
        self._attributes = None
        self._error_info = None
        self._script = None
        self._wrapup_timeout_ms = None
        self._wrapup_skipped = None
        self._alerting_timeout_ms = None
        self._provider = None
        self._external_contact = None
        self._external_organization = None
        self._wrapup = None
        self._conversation_routing_data = None
        self._peer = None
        self._screen_recording_state = None
        self._flagged_reason = None
        self._journey_context = None
        self._start_acw_time = None
        self._end_acw_time = None
        self._outbound_preview = None
        self._voicemail = None
        self._callback_numbers = None
        self._callback_user_name = None
        self._skip_enabled = None
        self._external_campaign = None
        self._timeout_seconds = None
        self._callback_scheduled_time = None
        self._automated_callback_config_id = None

    @property
    def id(self):
        """
        Gets the id of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The id of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param id: The id of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The name of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param name: The name of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        
        self._name = name

    @property
    def address(self):
        """
        Gets the address of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The address of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param address: The address of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        
        self._address = address

    @property
    def start_time(self):
        """
        Gets the start_time of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The start_time of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param start_time: The start_time of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: datetime
        """
        
        self._start_time = start_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The connected_time of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param connected_time: The connected_time of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def end_time(self):
        """
        Gets the end_time of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The end_time of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param end_time: The end_time of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: datetime
        """
        
        self._end_time = end_time

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The start_hold_time of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param start_hold_time: The start_hold_time of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def purpose(self):
        """
        Gets the purpose of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The purpose of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """
        Sets the purpose of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param purpose: The purpose of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        
        self._purpose = purpose

    @property
    def state(self):
        """
        Gets the state of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The state of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param state: The state of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        allowed_values = ["alerting", "dialing", "contacting", "offering", "connected", "disconnected", "terminated", "converting", "uploading", "transmitting", "scheduled", "none"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def direction(self):
        """
        Gets the direction of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The direction of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param direction: The direction of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for direction -> " + direction)
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The disconnect_type of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param disconnect_type: The disconnect_type of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        allowed_values = ["endpoint", "client", "system", "transfer", "timeout", "transfer.conference", "transfer.consult", "transfer.forward", "transfer.noanswer", "transfer.notavailable", "transport.failure", "error", "peer", "other", "spam", "uncallable"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def held(self):
        """
        Gets the held of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The held of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param held: The held of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: bool
        """
        
        self._held = held

    @property
    def wrapup_required(self):
        """
        Gets the wrapup_required of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The wrapup_required of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_required

    @wrapup_required.setter
    def wrapup_required(self, wrapup_required):
        """
        Sets the wrapup_required of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param wrapup_required: The wrapup_required of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: bool
        """
        
        self._wrapup_required = wrapup_required

    @property
    def wrapup_prompt(self):
        """
        Gets the wrapup_prompt of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The wrapup_prompt of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._wrapup_prompt

    @wrapup_prompt.setter
    def wrapup_prompt(self, wrapup_prompt):
        """
        Sets the wrapup_prompt of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param wrapup_prompt: The wrapup_prompt of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        
        self._wrapup_prompt = wrapup_prompt

    @property
    def user(self):
        """
        Gets the user of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The user of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: ConversationCallbackEventTopicUriReference
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param user: The user of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: ConversationCallbackEventTopicUriReference
        """
        
        self._user = user

    @property
    def queue(self):
        """
        Gets the queue of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The queue of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: ConversationCallbackEventTopicUriReference
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param queue: The queue of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: ConversationCallbackEventTopicUriReference
        """
        
        self._queue = queue

    @property
    def team(self):
        """
        Gets the team of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The team of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: ConversationCallbackEventTopicUriReference
        """
        return self._team

    @team.setter
    def team(self, team):
        """
        Sets the team of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param team: The team of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: ConversationCallbackEventTopicUriReference
        """
        
        self._team = team

    @property
    def attributes(self):
        """
        Gets the attributes of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The attributes of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param attributes: The attributes of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: dict(str, str)
        """
        
        self._attributes = attributes

    @property
    def error_info(self):
        """
        Gets the error_info of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The error_info of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: ConversationCallbackEventTopicErrorBody
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param error_info: The error_info of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: ConversationCallbackEventTopicErrorBody
        """
        
        self._error_info = error_info

    @property
    def script(self):
        """
        Gets the script of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The script of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: ConversationCallbackEventTopicUriReference
        """
        return self._script

    @script.setter
    def script(self, script):
        """
        Sets the script of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param script: The script of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: ConversationCallbackEventTopicUriReference
        """
        
        self._script = script

    @property
    def wrapup_timeout_ms(self):
        """
        Gets the wrapup_timeout_ms of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The wrapup_timeout_ms of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: int
        """
        return self._wrapup_timeout_ms

    @wrapup_timeout_ms.setter
    def wrapup_timeout_ms(self, wrapup_timeout_ms):
        """
        Sets the wrapup_timeout_ms of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param wrapup_timeout_ms: The wrapup_timeout_ms of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: int
        """
        
        self._wrapup_timeout_ms = wrapup_timeout_ms

    @property
    def wrapup_skipped(self):
        """
        Gets the wrapup_skipped of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The wrapup_skipped of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_skipped

    @wrapup_skipped.setter
    def wrapup_skipped(self, wrapup_skipped):
        """
        Sets the wrapup_skipped of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param wrapup_skipped: The wrapup_skipped of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: bool
        """
        
        self._wrapup_skipped = wrapup_skipped

    @property
    def alerting_timeout_ms(self):
        """
        Gets the alerting_timeout_ms of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The alerting_timeout_ms of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: int
        """
        return self._alerting_timeout_ms

    @alerting_timeout_ms.setter
    def alerting_timeout_ms(self, alerting_timeout_ms):
        """
        Sets the alerting_timeout_ms of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param alerting_timeout_ms: The alerting_timeout_ms of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: int
        """
        
        self._alerting_timeout_ms = alerting_timeout_ms

    @property
    def provider(self):
        """
        Gets the provider of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The provider of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param provider: The provider of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        
        self._provider = provider

    @property
    def external_contact(self):
        """
        Gets the external_contact of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The external_contact of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: ConversationCallbackEventTopicUriReference
        """
        return self._external_contact

    @external_contact.setter
    def external_contact(self, external_contact):
        """
        Sets the external_contact of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param external_contact: The external_contact of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: ConversationCallbackEventTopicUriReference
        """
        
        self._external_contact = external_contact

    @property
    def external_organization(self):
        """
        Gets the external_organization of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The external_organization of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: ConversationCallbackEventTopicUriReference
        """
        return self._external_organization

    @external_organization.setter
    def external_organization(self, external_organization):
        """
        Sets the external_organization of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param external_organization: The external_organization of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: ConversationCallbackEventTopicUriReference
        """
        
        self._external_organization = external_organization

    @property
    def wrapup(self):
        """
        Gets the wrapup of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The wrapup of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: ConversationCallbackEventTopicWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param wrapup: The wrapup of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: ConversationCallbackEventTopicWrapup
        """
        
        self._wrapup = wrapup

    @property
    def conversation_routing_data(self):
        """
        Gets the conversation_routing_data of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The conversation_routing_data of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: ConversationCallbackEventTopicConversationRoutingData
        """
        return self._conversation_routing_data

    @conversation_routing_data.setter
    def conversation_routing_data(self, conversation_routing_data):
        """
        Sets the conversation_routing_data of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param conversation_routing_data: The conversation_routing_data of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: ConversationCallbackEventTopicConversationRoutingData
        """
        
        self._conversation_routing_data = conversation_routing_data

    @property
    def peer(self):
        """
        Gets the peer of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The peer of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._peer

    @peer.setter
    def peer(self, peer):
        """
        Sets the peer of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param peer: The peer of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        
        self._peer = peer

    @property
    def screen_recording_state(self):
        """
        Gets the screen_recording_state of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The screen_recording_state of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._screen_recording_state

    @screen_recording_state.setter
    def screen_recording_state(self, screen_recording_state):
        """
        Sets the screen_recording_state of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param screen_recording_state: The screen_recording_state of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        
        self._screen_recording_state = screen_recording_state

    @property
    def flagged_reason(self):
        """
        Gets the flagged_reason of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The flagged_reason of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._flagged_reason

    @flagged_reason.setter
    def flagged_reason(self, flagged_reason):
        """
        Sets the flagged_reason of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param flagged_reason: The flagged_reason of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        allowed_values = ["general"]
        if flagged_reason.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for flagged_reason -> " + flagged_reason)
            self._flagged_reason = "outdated_sdk_version"
        else:
            self._flagged_reason = flagged_reason

    @property
    def journey_context(self):
        """
        Gets the journey_context of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The journey_context of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: ConversationCallbackEventTopicJourneyContext
        """
        return self._journey_context

    @journey_context.setter
    def journey_context(self, journey_context):
        """
        Sets the journey_context of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param journey_context: The journey_context of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: ConversationCallbackEventTopicJourneyContext
        """
        
        self._journey_context = journey_context

    @property
    def start_acw_time(self):
        """
        Gets the start_acw_time of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The start_acw_time of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: datetime
        """
        return self._start_acw_time

    @start_acw_time.setter
    def start_acw_time(self, start_acw_time):
        """
        Sets the start_acw_time of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param start_acw_time: The start_acw_time of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: datetime
        """
        
        self._start_acw_time = start_acw_time

    @property
    def end_acw_time(self):
        """
        Gets the end_acw_time of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The end_acw_time of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: datetime
        """
        return self._end_acw_time

    @end_acw_time.setter
    def end_acw_time(self, end_acw_time):
        """
        Sets the end_acw_time of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param end_acw_time: The end_acw_time of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: datetime
        """
        
        self._end_acw_time = end_acw_time

    @property
    def outbound_preview(self):
        """
        Gets the outbound_preview of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The outbound_preview of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: ConversationCallbackEventTopicDialerPreview
        """
        return self._outbound_preview

    @outbound_preview.setter
    def outbound_preview(self, outbound_preview):
        """
        Sets the outbound_preview of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param outbound_preview: The outbound_preview of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: ConversationCallbackEventTopicDialerPreview
        """
        
        self._outbound_preview = outbound_preview

    @property
    def voicemail(self):
        """
        Gets the voicemail of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The voicemail of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: ConversationCallbackEventTopicVoicemail
        """
        return self._voicemail

    @voicemail.setter
    def voicemail(self, voicemail):
        """
        Sets the voicemail of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param voicemail: The voicemail of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: ConversationCallbackEventTopicVoicemail
        """
        
        self._voicemail = voicemail

    @property
    def callback_numbers(self):
        """
        Gets the callback_numbers of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The callback_numbers of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: list[str]
        """
        return self._callback_numbers

    @callback_numbers.setter
    def callback_numbers(self, callback_numbers):
        """
        Sets the callback_numbers of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param callback_numbers: The callback_numbers of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: list[str]
        """
        
        self._callback_numbers = callback_numbers

    @property
    def callback_user_name(self):
        """
        Gets the callback_user_name of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The callback_user_name of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._callback_user_name

    @callback_user_name.setter
    def callback_user_name(self, callback_user_name):
        """
        Sets the callback_user_name of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param callback_user_name: The callback_user_name of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        
        self._callback_user_name = callback_user_name

    @property
    def skip_enabled(self):
        """
        Gets the skip_enabled of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The skip_enabled of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: bool
        """
        return self._skip_enabled

    @skip_enabled.setter
    def skip_enabled(self, skip_enabled):
        """
        Sets the skip_enabled of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param skip_enabled: The skip_enabled of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: bool
        """
        
        self._skip_enabled = skip_enabled

    @property
    def external_campaign(self):
        """
        Gets the external_campaign of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The external_campaign of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: bool
        """
        return self._external_campaign

    @external_campaign.setter
    def external_campaign(self, external_campaign):
        """
        Sets the external_campaign of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param external_campaign: The external_campaign of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: bool
        """
        
        self._external_campaign = external_campaign

    @property
    def timeout_seconds(self):
        """
        Gets the timeout_seconds of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The timeout_seconds of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: int
        """
        return self._timeout_seconds

    @timeout_seconds.setter
    def timeout_seconds(self, timeout_seconds):
        """
        Sets the timeout_seconds of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param timeout_seconds: The timeout_seconds of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: int
        """
        
        self._timeout_seconds = timeout_seconds

    @property
    def callback_scheduled_time(self):
        """
        Gets the callback_scheduled_time of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The callback_scheduled_time of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: datetime
        """
        return self._callback_scheduled_time

    @callback_scheduled_time.setter
    def callback_scheduled_time(self, callback_scheduled_time):
        """
        Sets the callback_scheduled_time of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param callback_scheduled_time: The callback_scheduled_time of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: datetime
        """
        
        self._callback_scheduled_time = callback_scheduled_time

    @property
    def automated_callback_config_id(self):
        """
        Gets the automated_callback_config_id of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The automated_callback_config_id of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._automated_callback_config_id

    @automated_callback_config_id.setter
    def automated_callback_config_id(self, automated_callback_config_id):
        """
        Sets the automated_callback_config_id of this ConversationCallbackEventTopicCallbackMediaParticipant.


        :param automated_callback_config_id: The automated_callback_config_id of this ConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        
        self._automated_callback_config_id = automated_callback_config_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ValidateWorkPlanResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ValidateWorkPlanResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'work_plan': 'WorkPlanReference',
            'valid': 'bool',
            'messages': 'ValidateWorkPlanMessages'
        }

        self.attribute_map = {
            'work_plan': 'workPlan',
            'valid': 'valid',
            'messages': 'messages'
        }

        self._work_plan = None
        self._valid = None
        self._messages = None

    @property
    def work_plan(self):
        """
        Gets the work_plan of this ValidateWorkPlanResponse.
        The work plan reference associated with this response

        :return: The work_plan of this ValidateWorkPlanResponse.
        :rtype: WorkPlanReference
        """
        return self._work_plan

    @work_plan.setter
    def work_plan(self, work_plan):
        """
        Sets the work_plan of this ValidateWorkPlanResponse.
        The work plan reference associated with this response

        :param work_plan: The work_plan of this ValidateWorkPlanResponse.
        :type: WorkPlanReference
        """
        
        self._work_plan = work_plan

    @property
    def valid(self):
        """
        Gets the valid of this ValidateWorkPlanResponse.
        Whether the work plan is valid or not

        :return: The valid of this ValidateWorkPlanResponse.
        :rtype: bool
        """
        return self._valid

    @valid.setter
    def valid(self, valid):
        """
        Sets the valid of this ValidateWorkPlanResponse.
        Whether the work plan is valid or not

        :param valid: The valid of this ValidateWorkPlanResponse.
        :type: bool
        """
        
        self._valid = valid

    @property
    def messages(self):
        """
        Gets the messages of this ValidateWorkPlanResponse.
        Validation messages for this work plan

        :return: The messages of this ValidateWorkPlanResponse.
        :rtype: ValidateWorkPlanMessages
        """
        return self._messages

    @messages.setter
    def messages(self, messages):
        """
        Sets the messages of this ValidateWorkPlanResponse.
        Validation messages for this work plan

        :param messages: The messages of this ValidateWorkPlanResponse.
        :type: ValidateWorkPlanMessages
        """
        
        self._messages = messages

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

